==> haskell-sandwich-0.2.2.0-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.2.2.0
visibility:           public
id:                   sandwich-0.2.2.0-19QlN2w5hS8CuQK0PCuEGL
key:                  sandwich-0.2.2.0-19QlN2w5hS8CuQK0PCuEGL
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  b82e173b885f3ce79237ee287b48754f
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH Test.Sandwich.Util.Process

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util
    Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.RunTimes
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types
    Test.Sandwich.Golden.Update Test.Sandwich.Internal.Formatters
    Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.2.2.0-19QlN2w5hS8CuQK0PCuEGL
depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    brick-2.4-CHFk9HifTyXCoRkygr8Six bytestring-0.11.5.3
    colour-2.3.6-Es9wrqLKeClLAeJW79jO2p containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 free-5.2-LavBzzjIwTh2GJScdhp5qt
    haskell-src-exts-1.23.1-BPssFzdsWmmITxGiP2kzCz
    lifted-async-0.11.0-AVvDRMioD315uY7lKjj0uo
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-control-1.0.3.1-5KQQUvViYP35kwtWEUOPGs
    monad-logger-0.3.42-LuCAjjjmxzACtBdHBvTKdG mtl-2.2.2
    optparse-applicative-0.18.1.0-t4C6chS8YH5x9x9VuRkT0
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp process-1.6.18.0
    retry-0.9.3.1-IY64eTdMZLhC7kIJKe8e84
    safe-0.3.21-JMKA2bKqr97GM6r3OADsOi
    safe-exceptions-0.1.7.4-E2jhex6cl0w6t2rEagsyOt stm-2.5.1.0
    string-interpolate-0.3.4.0-GqcBTkb5hyW1EHq3eTNtoJ
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-72fNkPW8m0RFmUAZLkd9QA
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS
    vty-6.2-5dKzRMimj0F1D1HuIfPTzr
    vty-crossplatform-0.4.0.0-AvgaBYwTKmn8fQcuLfkpYM

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandwich-0.2.2.0-14-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.2.2.0
visibility:           public
id:                   sandwich-0.2.2.0-BQivPDzv8EM513WsJlxXTV
key:                  sandwich-0.2.2.0-BQivPDzv8EM513WsJlxXTV
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  8588aa34b9307a1693f57fb624177b8c
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH Test.Sandwich.Util.Process

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util
    Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.RunTimes
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types
    Test.Sandwich.Golden.Update Test.Sandwich.Internal.Formatters
    Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/sandwich-0.2.2.0
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/sandwich-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/sandwich-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.2.2.0-BQivPDzv8EM513WsJlxXTV
depends:
    aeson-2.2.0.0-C0AkopVKntgCgZgm8TP6Wj
    ansi-terminal-1.1-4EeIQsn6Wrq78PCXTndXTh
    async-2.2.5-1ovq96REeQVKYsP5cduurl base-4.18.3.0
    brick-2.5-JOnWOQLcNQWCBERbPPQnG2 bytestring-0.11.5.4
    colour-2.3.6-DoApLSa6gBO3p6mb77xRwR containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.301.0 free-5.2-GjBgjt73BB74JXsIg5MCCe
    haskell-src-exts-1.23.1-B0H4hEPY8M8ExexllKZ3We
    lifted-async-0.11.0-1JylZ7TlCL0DorxIb2pjoe
    microlens-0.4.14.0-4ENPj0tHNR0GzcdT8Xo5Q8
    microlens-th-0.4.3.17-F1IcXkuPeIB4kMaxwhk9vS
    monad-control-1.0.3.1-FK5MwN7CLMeDFbgWPeqycv
    monad-logger-0.3.42-1gXz0WBj0vGBH7mblxUm91 mtl-2.3.1
    optparse-applicative-0.18.1.0-BYVre8yzbBOKektbxJ0fjC
    pretty-show-1.10-IMyOnqPwisgFJLGoHg4EWf process-1.6.19.0
    retry-0.9.3.1-HWGehCawEfd4o7XZUYA2Cu
    safe-0.3.21-40SDg1d9ZKLLr4MVwyQcdM
    safe-exceptions-0.1.7.4-Ro10nNdK1sGhfCK0np8W0 stm-2.5.1.0
    string-interpolate-0.3.4.0-7wtlsSPW7UsJc0vHzAqqD4
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 transformers-base-0.4.6-KecQozQ2bJs3HLDcaEYSEy
    unix-2.8.6.0 unliftio-core-0.2.1.0-CtDanxECkbwJ3FHnCY1MPO
    vector-0.13.2.0-BINMV7y6ibUKgFTnLXEi1A
    vty-6.2-24OTVSAh8AUKPMJVuGQjH5
    vty-crossplatform-0.4.0.0-BBLjeOQnXjcJfW68rQCmIH

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
